@@ -7,7 +7,7 @@ use File::Path qw( make_path );
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '1.97'; # VERSION
+our $VERSION = '1.98'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -115,6 +115,11 @@ sub setup_installer
     $list{'JSON::XS'}++;
   }
   
+  if(my($alien) = grep { $_->isa('Dist::Zilla::Plugin::Alien') } @{ $self->zilla->plugins })
+  {
+    $list{$_}++ foreach keys %{ $alien->module_build_args->{alien_bin_requires} };
+  }
+  
   foreach my $lib (@{ $self->diag })
   {
     if($lib =~ /^-(.*)$/)
@@ -183,7 +188,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 1.97
+version 1.98
 
 =head1 SYNOPSIS
 
